@@ -1,6 +1,5 @@
 """Game markers, like counters and etc
 """
-from typing import Literal
 import collections
 from dataclasses import dataclass, field
 from dataclasses_json import dataclass_json, config
@@ -10,7 +9,7 @@ from bgameb.base import Base
 @dataclass_json
 @dataclass(repr=False)
 class BaseMarker(Base):
-    """Base class for game stuff (like dices or cards)
+    """Base class for game markers
     """
 
     def __post_init__(self) -> None:
@@ -24,9 +23,9 @@ class Counter(BaseMarker):
     objects. It use `python collections/Counter
     <https://docs.python.org/3/library/collections.html#collections.Counter>`_
 
-    Aargs:
-        current (Counter): collections.Counter obkject
-                           is a current order of steps.
+    Attr:
+        - current (Counter): collections.Counter obkject
+                             is a current order of steps.
     """
     current: collections.Counter = field(
         default_factory=collections.Counter,
@@ -48,18 +47,10 @@ class Counter(BaseMarker):
 class Step(BaseMarker):
     """Game steps or turns
 
-    Args:
-
+    Attr:
         - priority (int): priority queue number. Default to 0.
     """
     priority: int = 0
 
     def __post_init__(self) -> None:
         super().__post_init__()
-
-
-MARKERS = {
-    Counter.__name__.lower(): Counter,
-    Step.__name__.lower(): Step,
-    }
-MARKERS_TYPES = Literal['counter', 'step', ]
