@@ -3,13 +3,14 @@
 import random
 from collections import deque
 from heapq import heappop, heappush
-from typing import Tuple, Dict, Literal, List, Deque
+from typing import Tuple, Dict, List, Deque
 from dataclasses import dataclass, field, replace
 from dataclasses_json import config, dataclass_json
 from bgameb.base import Base
 from bgameb.markers import Step
 from bgameb.items import Card, Dice
 from bgameb.errors import ArrangeIndexError
+from bgameb.types import MARKERS_ITEMS
 
 
 @dataclass_json
@@ -20,6 +21,7 @@ class BaseTool(Base):
 
     def __post_init__(self) -> None:
         super().__post_init__()
+        self._types_to_add = MARKERS_ITEMS
 
 
 @dataclass_json
@@ -58,19 +60,7 @@ class Shaker(BaseTool):
 
 @dataclass_json
 @dataclass(repr=False)
-class Bag(BaseTool):
-    """Datastorage for ordered list of stuff. Isnt queue or stack.
-    Use it for hand with cards, graveyards, outside of the game cards
-    and etc.
-    """
-
-    def __post_init__(self) -> None:
-        super().__post_init__()
-
-
-@dataclass_json
-@dataclass(repr=False)
-class Deck(Bag):
+class Deck(BaseTool):
     """Deck object
 
     Deck ia a Bag subclass that contains Cards for
@@ -96,7 +86,7 @@ class Deck(Bag):
     def __post_init__(self) -> None:
         super().__post_init__()
 
-    def deal(self) -> None:
+    def deal(self) -> Deque[Card]:
         """Deal new random shuffled deck and save it to
         self.current
         """
@@ -111,12 +101,14 @@ class Deck(Bag):
 
         self.shuffle()
         self._logger.debug(f'Is deal cards: {self.current}')
+        return self.current
 
-    def shuffle(self) -> None:
+    def shuffle(self) -> Deque[Card]:
         """Random shuffle current deck
         """
         random.shuffle(self.current)
         self._logger.debug(f'Is shuffled: {self.current}')
+        return self.current
 
     def to_arrange(
         self,
@@ -156,7 +148,7 @@ class Deck(Bag):
         self,
         arranged: List[Card],
         last: Tuple[List[Card], List[Card]]
-            ) -> None:
+            ) -> Deque[Card]:
         """Concatenate new current deck from given arranged list and last of
         deck. Use to_arrange() method to get list to arrange and last.
 
@@ -177,6 +169,7 @@ class Deck(Bag):
                 f'Wrong to_arranged parts: {arranged=}, {last=}',
                 logger=self._logger
                 )
+        return self.current
 
     def search(
         self,
@@ -188,8 +181,8 @@ class Deck(Bag):
         Args:
             query (Dict[str, int]): dict with name of searched
                                     cards and count of searching
-            remove (bool): if True - remove cards from current deck.
-                           Default to True.
+            remove (bool): if True - remove searched cards from
+                           current deck. Default to True.
 
         Return:
             List[Card]: list of find cards
@@ -223,6 +216,46 @@ class Deck(Bag):
 
         return result
 
+    def get_random(
+        self,
+        count: int = 1,
+        remove: bool = True
+            ) -> List[Card]:
+        """Get random cards from current deck
+
+        Args:
+            count (int, optional): count of random cards. Defaults to 1.
+            remove (bool, optional): if True - remove random cards from
+                                     current deck. Default to True.
+
+        Returns:
+            List[Card]: list of random cards
+        """
+        if not self.current:
+            self._logger.debug(
+                'Is empty current deck. Random cards not choosed.'
+                    )
+            return []
+        if not remove:
+            result = random.choices(self.current, k=count)
+            self._logger.debug(
+                f'Random choised cards without remove: {result}'
+                    )
+            return result
+        else:
+            result = []
+            for _ in range(count):
+                if self.current:
+                    choice = random.choice(self.current)
+                    result.append(choice)
+                    self.current.remove(choice)
+                else:
+                    break
+            self._logger.debug(
+                f'Random choised cards with remove: {result}'
+                    )
+            return result
+
 
 @dataclass_json
 @dataclass
@@ -230,8 +263,7 @@ class Order:
     """Order of steps priority queue. Isnt tradesafe.
     Is used only for define game steps order.
 
-    Args:
-
+    Attr:
         - current List[Tuple[int, Components]]: priority queue list
     """
     current: List[Tuple[int, Step]] = field(
@@ -275,8 +307,7 @@ class Order:
 class Steps(BaseTool):
     """Game steps order object
 
-    Args:
-
+    Attr:
         - current (Order): current order of steps.
     """
     current: Order = field(
@@ -288,7 +319,7 @@ class Steps(BaseTool):
     def __post_init__(self) -> None:
         super().__post_init__()
 
-    def deal(self):
+    def deal(self) -> Order:
         """Clear current order and create new current order
         """
         self.current.clear()
@@ -298,12 +329,4 @@ class Steps(BaseTool):
                 step = replace(self[comp])
                 self.current.put(step)
         self._logger.debug(f'Is deal order of turn: {self.current}')
-
-
-TOOLS = {
-    Shaker.__name__.lower(): Shaker,
-    Bag.__name__.lower(): Bag,
-    Deck.__name__.lower(): Deck,
-    Steps.__name__.lower(): Steps,
-    }
-TOOLS_TYPES = Literal['shaker', 'bag', 'deck', 'steps']
+        return self.current
